@@ -58,6 +58,17 @@ I2C_MEM_UID          =24
 I2C_MEM_ID           =32+2
 
 
+Positive_test_result         = 0
+Negative_test_result         = 1
+Cassette_not_found           = 2
+Control_area_not_found       = 3
+Invalid_image_identifier     = 4
+Unexpected_exception         = 5
+
+Unknown                      = 6
+Wrong_cassette               = 7
+Taking_picture_fail          = 8
+
 DEVICE_STATE_ORIGINAL            = 0x00
 
 DEVICE_STATE_CASSETTE_VALID      = 0xAB
@@ -92,13 +103,6 @@ CASSETTE_STATUS_FLAG     = 0x80
 #                   ]
 
 
-Positive_test_result         = 0
-Negative_test_result         = 1
-Cassette_not_found           = 2
-Control_area_not_found       = 3
-Invalid_image_identifier     = 4
-Unexpected_exception         = 5
-Unknown                      = 6
 
 
 #  stacked slot index  #
@@ -193,4 +197,12 @@ popUp = None
 MAX_PROFILES = 2
 #trans = None
 
+
+POSITIVE = '0'
+NEGATIVE = '1'
+INVALID  = '2'
+NO_ID    = '3'
+#UNKNOWN  = '3'
+
+
 #LANGUAGE_LIST = ['English', 'Spanish', 'French', 'Japanese', 'Indonesian', 'Arabic', 'Thailand', 'Chinese Traditional']
