@@ -13,10 +13,12 @@ parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
 
 import main_paras
+from main_paras import queueForGui, queueForResult, queueForCom
+
 from define import *
 from calibration import crop_rotate, final_save
 from qr_identify import qrIdentify
-from alg import target
+from algorithm import alg
 
 def camInstCreate(cameraIndex):
     try:
@@ -35,112 +37,56 @@ def camInstCreate(cameraIndex):
 
 camera_sem = threading.Semaphore()
 
-def cv_camera(cameraIndex,qrCode,event):
-    rtn=None
+
+def cv_camera(cameraIndex,qrCode, ext, event):
+    s = False
+    img =None
     for i in range(5):
         camera_sem.acquire()    
         try:
             cam=camInstCreate(cameraIndex)
-            
             s, img=cam.read()
-#             time.sleep(1)
-#             s, img=cam.read()
             if s:
-                print('got image')
-                #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png', img)
-                if qrCode!=None:   ## got Qr code, regular picture for detection.
-#                    photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
-                    photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png'
-                    first_crop = crop_rotate(img)
-                    
-                    if main_paras.offLineMode():
-                        final_img, _ = target.adjust(img, first_crop)
-                        photo = final_img[1]+'_'+photo
-                    else:
-                        #print('image deal')
-                        final_img, _ = target.adjust(img, first_crop, simple = True)
-                        #print('image deal done')
-                    imageFile=IMG_PATH+photo
-                    if final_save(final_img[0],imageFile):
-                        cam.release()
-                        camera_sem.release()
-                        rtn=photo
-                        break;
-                else: ## No Qr code, identify it from image.
-                    print('qr image')
-                    #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png', img)
-                    photo=qrIdentify(img);
-                    cam.release()
-                    camera_sem.release()
-                    if photo == None:
-                        rtn=NON_QR
-                    else:
-                        rtn=photo
-                    break;
-            else:
-                print("Photo taking failed!",qrCode, time.strftime('%Y%m%d%H%M%S'))
+                cam.release()
+                camera_sem.release()
+                break;
         except cv2.error as cv2Error:
             print("takePhoto cv2 Error: ", cv2Error)
         except Exception as e:
             print("takePhoto Exception: ", e)
     
+        camera_sem.release()            
         if cam !=None:
             cam.release()
-        camera_sem.release()            
         event.wait(2)
         if event.isSet():
             break;
-    return rtn
-    
-def fsw_camera(cameraIndex,qrCode,event):
-    rtn=None
-    
-    camera_sem.acquire()    
-    #fswebcam -v --no-banner -d /dev/video0 -r 1600x1200 -p YUYV -S 10 test.png
-    try:
-        cmd = 'fswebcam -v --no-banner -d /dev/video'+str(cameraIndex)+' -r 1600x1200 -p YUYV -S 10 test'+str(cameraIndex)+'.png'
-        result=subprocess.check_output([cmd], shell=True).decode("utf-8")
-
-        img = cv2.imread('test'+str(cameraIndex)+'.png')
+    if s:
         print('got image')
         #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png', img)
-        if qrCode!=None:   ## got Qr code, regular picture for detection.
-#                    photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
-            photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png'
-            first_crop = crop_rotate(img)
-            
-            if main_paras.offLineMode():
-                final_img, _ = target.adjust(img, first_crop)
-                photo = final_img[1]+'_'+photo
-            else:
-                #print('image deal')
-                final_img, _ = target.adjust(img, first_crop, simple = True)
-                #print('image deal done')
-            imageFile=IMG_PATH+photo
-            if final_save(final_img[0],imageFile):
-                rtn=photo
-                
-        else: ## No Qr code, identify it from image.
-            print('qr image')
-            #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', img)
-            photo=qrIdentify(img);
-            if photo == None:
-                rtn=NON_QR
-            else:
-                rtn=photo
-            
-    except cv2.error as cv2Error:
-        print("takePhoto cv2 Error: ", cv2Error)
-    except Exception as e:
-        print("takePhoto Exception: ", e)
-    camera_sem.release()
-    try:
-        os.remove('test'+str(cameraIndex)+'.png')
-    except Exception as err:
-        print(err)
-    return rtn
+        if qrCode == None:
+            #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png', img)
+            qrCode = qrIdentify(img)
+        
+        if qrCode==None:  
+            return NO_ID
+        
+        photo=qrCode+ext+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.png'
+
+        final_img, identifier = alg.target_cut(img)
+        if identifier == INVALID:
+            return INVALID
+            #print('image deal done')
+        imageFile=IMG_PATH+photo
+        if final_save(final_img,imageFile):
+            return photo
+    else:
+        print("Photo taking failed!",qrCode, time.strftime('%Y%m%d%H%M%S'))
+        
+    return None
     
-def takePhoto(cameraIndex,qrCode,event):
+    
+def takePhoto(cameraIndex, qrCode, ext, event):
     rtn = None
     print('in takePhoto')
 #     #fswebcam -v --no-banner -d /dev/video0 -r 1600x1200 -p YUYV -S 10 test.png
@@ -148,7 +94,7 @@ def takePhoto(cameraIndex,qrCode,event):
 #     result=subprocess.check_output([cmd], shell=True).decode("utf-8")
 #     print('result:',result)
 #     return
-    rtn=cv_camera(cameraIndex,qrCode,event);
+    rtn=cv_camera(cameraIndex,qrCode, ext, event);
     #rtn=fsw_camera(cameraIndex,qrCode,event);
     
     print('takePhoto return')
@@ -170,27 +116,6 @@ def take_photo_test(cameraIndex,qrCode,event):
                 original = str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')
                 new = original+'_new'
                 cv2.imwrite(original+'.jpg', img)
-#                 newImg=imageFilter(img)
-#                 cv2.imwrite(new+'.jpg', newImg)
-#                 if qrCode!=None:   ## got Qr code, regular picture for detection.
-#                     photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
-#                     imageFile=IMG_PATH+photo
-#                     if crop_rotate(img,imageFile):
-#                         cam.release()
-#                         camera_sem.release()
-#                         rtn=photo
-#                         break;
-#                 else: ## No Qr code, identify it from image.
-#                     print('qr image')
-#                     #cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', img)
-#                     photo=qrIdentify(img);
-#                     cam.release()
-#                     camera_sem.release()
-#                     if photo == None:
-#                         rtn=NON_QR
-#                     else:
-#                         rtn=photo
-#                     break;
             else:
                 print("Photo taking failed!",qrCode, time.strftime('%Y%m%d%H%M%S'))
         except cv2.error as cv2Error:
@@ -248,16 +173,24 @@ class TakePhotoProcedure(threading.Thread):
                 break;
             
     def procedure(self,photoIndex):
-        if self.qrCode != None:
-            photoFile=takePhoto(self.camera, self.qrCode+'_'+str(self.slotIndex)+'_'+str(photoIndex), self.event)
+        photoFile=takePhoto(self.camera, self.qrCode, '_'+str(self.slotIndex)+'_'+str(photoIndex), self.event)
+        print('in take_photo, procedure:',photoFile)
+        if(photoFile ==None ):
+            item=[self.slotIndex, Taking_picture_fail, self.qrCode, '']
+        elif photoFile == NO_ID:
+            item=[self.slotIndex, Wrong_cassette, self.qrCode, '']
+        elif photoFile == INVALID:
+            item=[self.slotIndex, Invalid_image_identifier, self.qrCode, '']
+        else: 
+            item=[]
+        if item == []:
+            self.qCom.put(photoFile)
         else:
-            photoFile=takePhoto(self.camera, None, self.event) ## For Qr code
-        if(photoFile !=None ):
-            print('in take_photo, procedure:',photoFile)
-            if main_paras.offLineMode():
-                main_paras.queueForOffLine.put(photoFile)
-            else:
-                self.qCom.put(photoFile)
+            queueForGui.put(item)
+        
+        
+        
+        
         
         
    
